@@ -1,14 +1,15 @@
 !
-!  This file is part of MUMPS 5.1.1, released
-!  on Mon Mar 20 14:34:33 UTC 2017
+!  This file is part of MUMPS 5.3.5, released
+!  on Thu Oct 22 09:29:08 UTC 2020
 !
 !
-!  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
-!  University of Bordeaux.
+!  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+!  Mumps Technologies, University of Bordeaux.
 !
 !  This version of MUMPS is provided to you free of charge. It is
-!  released under the CeCILL-C license:
-!  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
+!  released under the CeCILL-C license 
+!  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
+!  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
 !
       INCLUDE 'zmumps_root.h'
       TYPE ZMUMPS_STRUC
@@ -71,6 +72,12 @@
 !    ---------------------------------------------
         INTEGER, DIMENSION(:), POINTER :: PERM_IN
 !
+!    ----------------
+!    Format by blocks
+!    ----------------
+        INTEGER :: NBLK, pad5
+        INTEGER, DIMENSION(:), POINTER :: BLKPTR
+        INTEGER, DIMENSION(:), POINTER :: BLKVAR
 !
 ! ******************
 ! INPUT/OUTPUT data 
@@ -83,22 +90,26 @@
         COMPLEX(kind=8), DIMENSION(:), POINTER :: RHS, REDRHS
         COMPLEX(kind=8), DIMENSION(:), POINTER :: RHS_SPARSE
         COMPLEX(kind=8), DIMENSION(:), POINTER :: SOL_loc
+        COMPLEX(kind=8), DIMENSION(:), POINTER :: RHS_loc
         INTEGER, DIMENSION(:), POINTER :: IRHS_SPARSE
         INTEGER, DIMENSION(:), POINTER :: IRHS_PTR
         INTEGER, DIMENSION(:), POINTER :: ISOL_loc
-        INTEGER ::  LRHS, NRHS, NZ_RHS, LSOL_loc, LREDRHS
-        INTEGER ::  pad5
+        INTEGER, DIMENSION(:), POINTER :: IRHS_loc
+        INTEGER :: LRHS, NRHS, NZ_RHS, Nloc_RHS, LRHS_loc, LREDRHS
+        INTEGER :: LSOL_loc, pad6
 !    ----------------------------
 !    Control parameters,
 !    statistics and output data
 !    ---------------------------
-        INTEGER ::  ICNTL(40)
-        INTEGER ::  INFO(40) 
-        INTEGER :: INFOG(40)
+        INTEGER ::  ICNTL(60)
+        INTEGER ::  INFO(80) 
+        INTEGER :: INFOG(80)
         DOUBLE PRECISION ::  COST_SUBTREES
         DOUBLE PRECISION ::  CNTL(15)
         DOUBLE PRECISION ::  RINFO(40)
         DOUBLE PRECISION ::  RINFOG(40)
+! The options array for metis/parmetis
+        INTEGER ::  METIS_OPTIONS(40)
 !    ---------------------------------------------------------
 !    Permutations computed during analysis:
 !       SYM_PERM: Symmetric permutation 
@@ -138,7 +149,7 @@
 !    -----------
         CHARACTER(LEN=255) :: SAVE_DIR
         CHARACTER(LEN=255)  :: SAVE_PREFIX
-        CHARACTER(LEN=7)   ::  pad8  
+        CHARACTER(LEN=7)   ::  pad7  
 !
 !
 ! **********************
@@ -148,33 +159,24 @@
         INTEGER ::  INST_Number
 !       For MPI
         INTEGER ::  COMM_NODES, MYID_NODES, COMM_LOAD
-        INTEGER ::   MYID, NPROCS, NSLAVES
+        INTEGER ::  MYID, NPROCS, NSLAVES
         INTEGER ::  ASS_IRECV
-        INTEGER ::  LBUFR
-        INTEGER ::  LBUFR_BYTES
-        INTEGER, DIMENSION(:), POINTER ::  BUFR
 !       IS is used for the factors + workspace for contrib. blocks
         INTEGER, DIMENSION(:), POINTER :: IS
-!       IS1 (maxis1) contains working arrays computed 
-!       and used only during analysis
-        INTEGER, DIMENSION(:), POINTER :: IS1
-!       For analysis/facto/solve phases
-        INTEGER ::  MAXIS1, Deficiency
         INTEGER ::  KEEP(500)
 !       The following data/arrays are computed during the analysis
 !       phase and used during the factorization and solve phases.
         INTEGER ::  LNA
         INTEGER ::  NBSA
         INTEGER,POINTER,DIMENSION(:) :: STEP, NE_STEPS, ND_STEPS
-!  Info for pruning tree 
-        INTEGER,POINTER,DIMENSION(:) :: Step2node
-!  ---------------------
         INTEGER,POINTER,DIMENSION(:) :: FRERE_STEPS, DAD_STEPS
         INTEGER,POINTER,DIMENSION(:) :: FILS, FRTPTR, FRTELT
         INTEGER(8),POINTER,DIMENSION(:) :: PTRAR
         INTEGER,POINTER,DIMENSION(:) :: NA, PROCNODE_STEPS
-!       The two pointer arrays computed in facto and used by the solve
-!          (except the factors) are PTLUST_S and PTRFAC. 
+!       Info for pruning tree 
+        INTEGER,POINTER,DIMENSION(:) :: Step2node
+!       PTLUST_S and PTRFAC are two pointer arrays computed during
+!       factorization and used by the solve
         INTEGER, DIMENSION(:), POINTER :: PTLUST_S
         INTEGER(8), DIMENSION(:), POINTER :: PTRFAC
 !       main real working arrays for factorization/solve phases
@@ -246,32 +248,41 @@
         INTEGER, POINTER, DIMENSION(:) :: LRGROUPS
         INTEGER :: NBGRP,pad13
 !    Pointer encoding for FDM_F data
-        CHARACTER(LEN=1), DIMENSION(:), POINTER :: FDM_F_ENCODING
+        CHARACTER, DIMENSION(:), POINTER :: FDM_F_ENCODING
 !    Pointer array encoding BLR factors pointers
-        CHARACTER(LEN=1), DIMENSION(:), POINTER :: BLRARRAY_ENCODING
+        CHARACTER, DIMENSION(:), POINTER :: BLRARRAY_ENCODING
 !    Multicore
-        INTEGER :: LPOOL_AFTER_L0_OMP, LPOOL_BEFORE_L0_OMP
+        TYPE(ZMUMPS_L0OMPFAC_T),DIMENSION(:),POINTER :: L0_OMP_FACTORS
+        INTEGER :: LPOOL_A_L0_OMP, LPOOL_B_L0_OMP
         INTEGER :: L_PHYS_L0_OMP
         INTEGER :: L_VIRT_L0_OMP                                    
-        INTEGER :: LL0_OMP_MAPPING,pad15
+        INTEGER :: LL0_OMP_MAPPING, LL0_OMP_FACTORS
         INTEGER(8) :: THREAD_LA
+! Estimates before L0_OMP
+        INTEGER, DIMENSION(:,:), POINTER    :: I4_L0_OMP
+        INTEGER(8), DIMENSION(:,:), POINTER :: I8_L0_OMP
 ! Pool before L0_OMP
-        INTEGER, DIMENSION(:), POINTER :: IPOOL_BEFORE_L0_OMP
+        INTEGER, DIMENSION(:), POINTER :: IPOOL_B_L0_OMP
 ! Pool after L0_OMP
-        INTEGER, DIMENSION(:), POINTER :: IPOOL_AFTER_L0_OMP
+        INTEGER, DIMENSION(:), POINTER :: IPOOL_A_L0_OMP
 ! Subtrees
         INTEGER, DIMENSION(:), POINTER :: PHYS_L0_OMP
 ! Amalgamated subtrees
         INTEGER, DIMENSION(:), POINTER :: VIRT_L0_OMP
+! Mapping of amalgamated subtrees
+        INTEGER, DIMENSION(:), POINTER :: VIRT_L0_OMP_MAPPING
 ! From heaviest to lowest subtree
         INTEGER, DIMENSION(:), POINTER :: PERM_L0_OMP
 ! To get leafs in global pool
         INTEGER, DIMENSION(:), POINTER :: PTR_LEAFS_L0_OMP
-! Mapping of the subtrees
+! Mapping of the subtree nodes
         INTEGER, DIMENSION(:), POINTER :: L0_OMP_MAPPING
+! Mpi to omp - mumps agile
+        INTEGER, DIMENSION(:), POINTER :: MPITOOMP_PROCS_MAP
 ! for RR on root
         DOUBLE PRECISION, DIMENSION(:), POINTER :: SINGULAR_VALUES
         INTEGER ::  NB_SINGULAR_VALUES
+        INTEGER ::  Deficiency, pad16
 ! To know if OOC files are associated to a saved and so if they should be removed.
         LOGICAL :: ASSOCIATED_OOC_FILES
       END TYPE ZMUMPS_STRUC
