@@ -1,15 +1,16 @@
 /*
  *
- *  This file is part of MUMPS 5.2.1, released
- *  on Fri Jun 14 14:46:05 UTC 2019
+ *  This file is part of MUMPS 5.3.5, released
+ *  on Thu Oct 22 09:29:08 UTC 2020
  *
  *
- *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
- *  released under the CeCILL-C license:
- *  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
+ *  released under the CeCILL-C license 
+ *  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
+ *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
  *
  */
 #include "mumps_io_basic.h"
@@ -127,13 +128,9 @@ void*  mumps_async_thread_function_with_sem (void* arg){
  end:
    /* The main thread ordered the end of the IO thread (it changed sem_stop).
     We exit. */
-   if (1 == 1) { /* ssg */
-     pthread_exit(NULL);
-     return NULL;
-   }
-   return NULL;
+   pthread_exit(NULL);
 /* FIXME Not reached */
-/*   return NULL; */
+   return NULL;
 }
 MUMPS_INT mumps_test_request_th(MUMPS_INT* request_id,MUMPS_INT *flag){
   /* Tests if the request "request_id" has finished. It sets the flag  */
@@ -292,7 +289,7 @@ MUMPS_INT mumps_clean_request_th(MUMPS_INT* request_id){
   return 0;
 }
 MUMPS_INT mumps_low_level_init_ooc_c_th(MUMPS_INT* async, MUMPS_INT* ierr){
-  MUMPS_INT i, ret_code=0 /* ssg */;    
+  MUMPS_INT i, ret_code;    
   char buf[128];
   /* Computes the number of files needed. Uses ceil value. */
   *ierr=0;
