@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2009-2012 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2009-2012,2016,2017 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -41,19 +41,19 @@
 /**                methods.                                **/
 /**                                                        **/
 /**   DATES      : # Version 3.2  : from : 08 oct 1996     **/
-/**                                 to     13 sep 1998     **/
+/**                                 to   : 13 sep 1998     **/
 /**                # Version 3.3  : from : 01 oct 1998     **/
-/**                                 to     12 mar 1999     **/
+/**                                 to   : 12 mar 1999     **/
 /**                # Version 3.4  : from : 01 jun 2001     **/
-/**                                 to     01 jun 2001     **/
+/**                                 to   : 01 jun 2001     **/
 /**                # Version 4.0  : from : 12 jan 2004     **/
-/**                                 to     20 aug 2004     **/
+/**                                 to   : 20 aug 2004     **/
 /**                # Version 5.0  : from : 27 nov 2006     **/
-/**                                 to     29 may 2007     **/
+/**                                 to   : 29 may 2007     **/
 /**                # Version 5.1  : from : 26 oct 2009     **/
-/**                                 to     15 apr 2011     **/
-/**                # Version 6.0  : from : 23 fev 2011     **/
-/**                                 to     19 nov 2012     **/
+/**                                 to   : 15 apr 2011     **/
+/**                # Version 6.0  : from : 23 feb 2011     **/
+/**                                 to   : 02 jan 2017     **/
 /**                                                        **/
 /************************************************************/
 
@@ -171,6 +171,10 @@ static StratParamTab        bgraphbipartstparatab[] = { /* Method parameter list
                                 (byte *) &bgraphbipartstdefaultgg.param,
                                 (byte *) &bgraphbipartstdefaultgg.param.passnbr,
                                 NULL },
+                              { BGRAPHBIPARTSTMETHGP,  STRATPARAMINT,    "pass",
+                                (byte *) &bgraphbipartstdefaultgp.param,
+                                (byte *) &bgraphbipartstdefaultgp.param.passnbr,
+                                NULL },
                               { BGRAPHBIPARTSTMETHML,  STRATPARAMSTRAT,  "asc",
                                 (byte *) &bgraphbipartstdefaultml.param,
                                 (byte *) &bgraphbipartstdefaultml.param.stratasc,
@@ -324,7 +328,7 @@ const Strat * restrict const  strat)              /*+ Bipartitioning strategy
         compload0 = grafptr->compload0avg + savetab[0].compload0dlt;
         b0 = ((compload0 < grafptr->compload0min) ||
               (compload0 > grafptr->compload0max)) ? 1 : o;
-        compload0 = grafptr->compload0avg + savetab[1].compload0dlt;
+        compload0 = grafptr->compload0avg + grafptr->compload0dlt;
         b1 = ((compload0 < grafptr->compload0min) ||
               (compload0 > grafptr->compload0max)) ? 1 : o2;
 
