@@ -1,4 +1,4 @@
-/* Copyright 2007-2012 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007-2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -41,7 +41,7 @@
 /**   DATES      : # Version 5.1  : from : 11 nov 2007     **/
 /**                                 to   : 20 feb 2011     **/
 /**                # Version 6.0  : from : 03 apr 2012     **/
-/**                                 to   : 26 sep 2012     **/
+/**                                 to   : 22 may 2018     **/
 /**                                                        **/
 /**   NOTES      : # This code derives from the code of    **/
 /**                  vdgraph_separate_bd.c in version 5.0. **/
@@ -64,15 +64,18 @@
 /*                                */
 /**********************************/
 
-#define DGRAPHBANDGROWNAME          dgraphBand
+#define DGRAPHBANDGROWNAME          dgraphBand2
 #define DGRAPHBANDGROWEDGE(n)       bandedgelocnbr += vendloctax[n] - vertloctax[n]
-#define DGRAPHBANDGROWENQ1          for (queulocnum = 0; queulocnum < queulocnbr; queulocnum ++) { \
-                                      Gnum              vertlocnum;                                \
-                                                                                                   \
-                                      vertlocnum = queuloctab[queulocnum];                         \
-                                      vnumgsttax[vertlocnum] = bandvertlocnnd ++;                  \
-                                      DGRAPHBANDGROWEDGE (vertlocnum);                             \
-                                    }
+#define DGRAPHBANDGROWENQ1          do {                                                             \
+                                      Gnum              queulocnum;                                  \
+                                      for (queulocnum = 0; queulocnum < queulocnbr; queulocnum ++) { \
+                                        Gnum              vertlocnum;                                \
+                                                                                                     \
+                                        vertlocnum = queuloctab[queulocnum];                         \
+                                        vnumgsttax[vertlocnum] = bandvertlocnnd ++;                  \
+                                        DGRAPHBANDGROWEDGE (vertlocnum);                             \
+                                      }                                                              \
+                                    } while (0)
 #define DGRAPHBANDGROWENQ2          bandvertlocnnd ++
 #define DGRAPHBANDGROWENQ3                        /* Nothing more to send */
 #define DGRAPHBANDGROWENQ4          bandvertlocnnd ++
@@ -139,7 +142,6 @@ Gnum * const                        bandvertlocancptr) /*+ Pointer to flag set i
   const Gnum * restrict   edgegsttax;
   Gnum                    fronlocnum;
   int                     cheklocval;
-  int                     chekglbval;
   int                     procngbnum;
 
   if (dgraphGhst (grafptr) != 0) {                /* Compute ghost edge array if not already present */
@@ -149,27 +151,19 @@ Gnum * const                        bandvertlocancptr) /*+ Pointer to flag set i
 
   cheklocval = 0;
   bandvnumgstsiz = MAX ((grafptr->vertgstnbr * sizeof (Gnum)), (grafptr->procglbnbr * sizeof (int))); /* TRICK: re-use array for further error collective communications */
-  if ((bandvnumgsttax = memAlloc (bandvnumgstsiz)) == NULL) {
+ if ((bandvnumgsttax = memAlloc (bandvnumgstsiz)) == NULL) /* Error will be propagated by dgraphBand2*() */
     errorPrint ("dgraphBand: out of memory (1)");
-    cheklocval = 1;
+ else {
+    memSet (bandvnumgsttax, ~0, grafptr->vertgstnbr * sizeof (Gnum)); /* Reset part array */
+    bandvnumgsttax -= grafptr->baseval;
   }
-#ifdef SCOTCH_DEBUG_DGRAPH1                       /* This communication cannot be covered by a useful one */
-  if (MPI_Allreduce (&cheklocval, &chekglbval, 1, MPI_INT, MPI_MAX, grafptr->proccomm) != MPI_SUCCESS) {
-    errorPrint ("dgraphBand: communication error (1)");
-    return     (1);
+
+  if ((((grafptr->flagval & DGRAPHCOMMPTOP) != 0) ? dgraphBand2Ptop : dgraphBand2Coll)
+      (grafptr, fronlocnbr, fronloctab, distmax, bandvnumgsttax, &bandvertlvlnum, &bandvertlocnbr, &bandedgelocnbr) != 0) {
+    if (bandvnumgsttax != NULL)
+      memFree (bandvnumgsttax + grafptr->baseval);
+    return (1);
   }
-#else /* SCOTCH_DEBUG_DGRAPH1 */
-  chekglbval = cheklocval;
-#endif /* SCOTCH_DEBUG_DGRAPH1 */
-  if (chekglbval != 0)
-    return (1);
-
-  memSet (bandvnumgsttax, ~0, grafptr->vertgstnbr * sizeof (Gnum)); /* Reset part array */
-  bandvnumgsttax -= grafptr->baseval;
-
-  if ((((grafptr->flagval & DGRAPHCOMMPTOP) != 0) ? dgraphBandPtop : dgraphBandColl)
-      (grafptr, fronlocnbr, fronloctab, distmax, bandvnumgsttax, &bandvertlvlnum, &bandvertlocnbr, &bandedgelocnbr) != 0)
-    return (1);
 
   if (bandvertlvlptr != NULL)
     *bandvertlvlptr = bandvertlvlnum;
@@ -420,7 +414,7 @@ Gnum * const                        bandvertlocancptr) /*+ Pointer to flag set i
     Gnum              edgelocnnd;
 
     for (bandvertlocnum = bandgrafptr->baseval;   /* For all vertices that do not belong to the last level */
-         bandvertlocnum < bandvertlvlnum; bandvertlocnum ++) { 
+         bandvertlocnum < bandvertlvlnum; bandvertlocnum ++) {
       Gnum              vertlocnum;
       Gnum              bandedgelocnum;
 
