@@ -1,4 +1,4 @@
-/* Copyright 2010-2012,2014 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2010-2012,2014,2020 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -42,7 +42,7 @@
 /**                to be a band graph.                     **/
 /**                                                        **/
 /**   DATES      : # Version 6.0  : from : 05 jan 2010     **/
-/**                                 to   : 23 aug 2014     **/
+/**                                 to   : 21 feb 2020     **/
 /**                                                        **/
 /************************************************************/
 
@@ -94,7 +94,7 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
   const Anum                        domnnnd = thrdptr->domnnnd;
   const Anum                        domnnbr = grafptr->m.domnnbr;
   const Gnum                        crloval = grafptr->r.crloval;
-/*  const Gnum                        cmloval = grafptr->r.cmloval;*/
+  const Gnum                        cmloval = grafptr->r.cmloval;
   Anum * restrict const             parttax = grafptr->m.parttax;
   const Anum * restrict const       parotax = grafptr->r.m.parttax;
   const Gnum * restrict const       verttax = grafptr->s.verttax;
@@ -129,7 +129,7 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
   }
   if (velsmsk == 0) {                             /* If graph is too small to have any usable anchors */
 #ifdef KGRAPHMAPDFLOOPTHREAD
-    loopptr->abrtval = 1;                        /* We will leave during the first iteration */ /* ssg */
+    loopptr->abrtval = 1;                         /* We will leave during the first iteration */
 #else /* KGRAPHMAPDFLOOPTHREAD */
     return (1);
 #endif /* KGRAPHMAPDFLOOPTHREAD */
@@ -143,7 +143,7 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
     return (1);
 #endif /* KGRAPHMAPDFLOOPTHREAD */
   }
-    
+   
   if (velotax == NULL) {
     for (domnnum = domnbas; domnnum < domnnnd; domnnum ++)
       valotab[domnnum] = 1.0F;
@@ -201,10 +201,10 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
 #endif /* SCOTCH_DEBUG_KGRAPH2 */
       difotax[vertnum].partval = parttax[vertnum]; /* Set initial part by default */
       difotax[vertnum].diffval =
-      difotax[vertnum].fdifval = 
+      difotax[vertnum].fdifval =
       difotax[vertnum].mdisval =
       difotax[vertnum].mdidval =
-      difntax[vertnum].fdifval = 
+      difntax[vertnum].fdifval =
       difntax[vertnum].mdisval =
       difntax[vertnum].mdidval = 0.0F;
       velstax[vertnum] = vendtax[vertnum] - verttax[vertnum];
@@ -217,7 +217,7 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
 
     if (velstax[vancnnd + domnnum] <= 0) {
       vancval          =
-      vanctab[domnnum] = 0.0F; 
+      vanctab[domnnum] = 0.0F;
       velstax[vertnum] = -1;
     }
     else {
@@ -231,7 +231,7 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
     difntax[vertnum].diffval =                    /* In case of isolated anchors, do not risk overflow because of NaN */
     difotax[vertnum].fdifval =
     difotax[vertnum].mdisval =
-    difotax[vertnum].mdidval = 
+    difotax[vertnum].mdidval =
     difntax[vertnum].fdifval =
     difntax[vertnum].mdisval =
     difntax[vertnum].mdidval = 0.0F;              /* Do not consider migration costs for anchors */
@@ -247,7 +247,7 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
 #endif /* KGRAPHMAPDFLOOPTHREAD */
 
 #ifndef KGRAPHDIFFMAPPNONE
-  if (archPart (grafptr->m.archptr))   
+  if (archPart (grafptr->m.archptr))  
     mappflag = 0;
   else
     mappflag = 1;
@@ -273,8 +273,8 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
       Anum                partnbr;                /* Number of active parts */
       Anum                partnum;
       float               diffval;
-/*      float               signval;*/
-/*      Anum                paronum;*/
+      float               signval;
+      Anum                paronum;
       Anum                partcur;
 
       partnbr = 1;                                /* Keep vertex in first place to preserve its part */
@@ -294,7 +294,7 @@ KgraphMapDfThread * restrict  thrdptr)            /* Thread-dependent data */
         Anum                partval;
         Anum                partnum;
         Gnum                edloval;
-/*        Anum                distval;*/
+        Anum                distval;
 
         vertend = edgetax[edgenum];
         edloval = (float) ((edlotax != NULL) ? edlotax[edgenum] : 1);
@@ -396,14 +396,14 @@ endloop1 : ;
 
       if (parotax != NULL) {
         if (migrval == 0) {
-          difntax[vertnum].mdisval = 
+          difntax[vertnum].mdisval =
           difntax[vertnum].mdidval = 0;
         }
         else {
           if (parotax[vertnum] == sorttab[0].partval) {
             difntax[vertnum].mdisval = migrval / soplval;
             difntax[vertnum].mdidval = 0;
-          }  
+          } 
           else {
             difntax[vertnum].mdisval = 0;
             difntax[vertnum].mdidval = migrval / (velstax[vertnum] - soplval);
@@ -423,9 +423,9 @@ endloop1 : ;
       Gnum                edgenum;
       Gnum                edgennd;
       Anum                partnbr;                /* Number of active parts */
-/*      Anum                partnum;*/
+      Anum                partnum;
       float               diffval;
-/*      float               signval;*/
+      float               signval;
 
       partnbr = 1;                                /* Keep vertex in first place to preserve its part */
       sorttab[0].partval = domnnum;               /* Always keep initial part value                  */
@@ -495,17 +495,15 @@ endloop2 : ;
     difttax = (KgraphMapDfVertex *) difntax;      /* Swap old and new diffusion arrays          */
     difntax = (KgraphMapDfVertex *) difotax;      /* Casts to prevent IBM compiler from yelling */
     difotax = (KgraphMapDfVertex *) difttax;
-#ifdef KGRAPHMAPDFLOOPTHREAD
 abort1 : ;                                        /* If overflow occured, resume here */
+#ifdef KGRAPHMAPDFLOOPTHREAD
     threadBarrier (thrdptr);
 
     if (loopptr->abrtval == 1)                    /* If all threads need to abort */
       break;
 #endif /* KGRAPHMAPDFLOOPTHREAD */
   }
-#ifndef KGRAPHMAPDFLOOPTHREAD
 abort2 : ;
-#endif /* KGRAPHMAPDFLOOPTHREAD */
 
   for (vertnum = vertbas; vertnum < vertnnd; vertnum ++) /* Set new part distribution of local vertices */
     parttax[vertnum] = difntax[vertnum].partval;
